@@ -1,5 +1,3 @@
-import pkg_resources
-
 from .central import CentralMoments, central_moments
 from .resample import (
     bootstrap_confidence_interval,
@@ -8,13 +6,21 @@ from .resample import (
 )
 from .xcentral import xcentral_moments, xCentralMoments
 
+# updated versioning scheme
 try:
-    __version__ = pkg_resources.get_distribution("cmomy").version
+    from importlib.metadata import version as _version
+except ImportError:
+    # if the fallback library is missing, we are doomed.
+    from importlib_metadata import version as _version  # type: ignore[no-redef]
+
+try:
+    __version__ = _version("cmomy")
 except Exception:
     # Local copy or not installed with setuptools.
     # Disable minimum version checks on downstream libraries.
     __version__ = "999"
 
+
 __author__ = """William P. Krekelberg"""
 __email__ = "wpk@nist.gov"
 
